@@ -3,6 +3,7 @@ Ensure that layers and their convenience methods on the viewer
 have the same signatures and docstrings.
 """
 
+import gc
 import inspect
 import re
 from unittest.mock import MagicMock, call
@@ -12,8 +13,7 @@ import pytest
 from numpydoc.docscrape import ClassDoc, FunctionDoc
 
 import napari
-from napari import Viewer
-from napari import layers as module
+from napari import Viewer, layers as module
 from napari._tests.utils import check_viewer_functioning, layer_test_data
 from napari.utils.misc import camel_to_snake
 
@@ -42,7 +42,10 @@ def test_docstring(layer):
     # check summary section
     method_summary = ' '.join(method_doc['Summary'])  # join multi-line summary
 
-    summary_format = 'Add an? .+? layer to the layer list.'
+    if name == 'Image':
+        summary_format = 'Add one or more Image layers to the layer list.'
+    else:
+        summary_format = 'Add an? .+? layers? to the layer list.'
 
     assert re.match(
         summary_format, method_summary
@@ -96,7 +99,7 @@ def test_docstring(layer):
         assert method_returns == (
             'layer',
             f':class:`napari.layers.{name}` or list',
-            f'The newly-created {name.lower()} layer or list of {name.lower()} layers.',  # noqa: E501
+            f'The newly-created {name.lower()} layer or list of {name.lower()} layers.',
         ), f"improper 'Returns' section of '{method_name}'"
     else:
         assert method_returns == (
@@ -118,14 +121,14 @@ def test_signature(layer):
     fail_msg = f"signatures don't match for class {name}"
     if name == 'Image':
         # If Image just test that class params appear in method
-        for class_param in class_parameters.keys():
-            assert class_param in method_parameters.keys(), fail_msg
+        for class_param in class_parameters:
+            assert class_param in method_parameters, fail_msg
     else:
         assert class_parameters == method_parameters, fail_msg
 
 
 # plugin_manager fixture is added to prevent errors due to installed plugins
-@pytest.mark.parametrize('layer_type, data, ndim', layer_test_data)
+@pytest.mark.parametrize(('layer_type', 'data', 'ndim'), layer_test_data)
 def test_view(qtbot, napari_plugin_manager, layer_type, data, ndim):
     np.random.seed(0)
     viewer = getattr(napari, f'view_{layer_type.__name__.lower()}')(
@@ -144,11 +147,15 @@ def test_view_multichannel(qtbot, napari_plugin_manager):
     viewer = napari.view_image(data, channel_axis=-1, show=False)
     assert len(viewer.layers) == data.shape[-1]
     for i in range(data.shape[-1]):
-        assert np.all(viewer.layers[i].data == data.take(i, axis=-1))
+        np.testing.assert_array_equal(
+            viewer.layers[i].data, data.take(i, axis=-1)
+        )
     viewer.close()
 
 
 def test_kwargs_passed(monkeypatch):
+    import napari.view_layers
+
     viewer_mock = MagicMock(napari.Viewer)
     monkeypatch.setattr(napari.view_layers, 'Viewer', viewer_mock)
     napari.view_path(
@@ -162,3 +169,48 @@ def test_kwargs_passed(monkeypatch):
         call(title='my viewer'),
         call().open(path='some/path', name='img name', scale=(1, 2, 3)),
     ]
+
+
+# plugin_manager fixture is added to prevent errors due to installed plugins
+def test_imshow(qtbot, napari_plugin_manager):
+    shape = (10, 15)
+    ndim = len(shape)
+    np.random.seed(0)
+    data = np.random.random(shape)
+    viewer, layer = napari.imshow(data, channel_axis=None, show=False)
+    view = viewer.window._qt_viewer
+    check_viewer_functioning(viewer, view, data, ndim)
+    assert isinstance(layer, napari.layers.Image)
+    viewer.close()
+
+
+# plugin_manager fixture is added to prevent errors due to installed plugins
+def test_imshow_multichannel(qtbot, napari_plugin_manager):
+    """Test adding image."""
+    np.random.seed(0)
+    data = np.random.random((15, 10, 5))
+    viewer, layers = napari.imshow(data, channel_axis=-1, show=False)
+    assert len(layers) == data.shape[-1]
+    assert isinstance(layers, tuple)
+    for i in range(data.shape[-1]):
+        np.testing.assert_array_equal(layers[i].data, data.take(i, axis=-1))
+    viewer.close()
+    # Run a full garbage collection here so that any remaining viewer
+    # and related instances are removed for future tests that may use
+    # make_napari_viewer.
+    gc.collect()
+
+
+# plugin_manager fixture is added to prevent errors due to installed plugins
+def test_imshow_with_viewer(qtbot, napari_plugin_manager, make_napari_viewer):
+    shape = (10, 15)
+    ndim = len(shape)
+    np.random.seed(0)
+    data = np.random.random(shape)
+    viewer = make_napari_viewer()
+    viewer2, layer = napari.imshow(data, viewer=viewer, show=False)
+    assert viewer is viewer2
+    np.testing.assert_array_equal(data, layer.data)
+    view = viewer.window._qt_viewer
+    check_viewer_functioning(viewer, view, data, ndim)
+    viewer.close()
