@@ -306,6 +306,7 @@ class VispyLabelsLayer(VispyScalarFieldBaseLayer):
         ndims = len(event.offset)
 
         if self.node._texture.shape[:ndims] != raw_displayed.shape[:ndims]:
+            # TODO: I'm confused by this whole process; should this refresh be changed?
             self.layer.refresh()
             return
 
@@ -317,6 +318,7 @@ class VispyLabelsLayer(VispyScalarFieldBaseLayer):
     def reset(self, event=None) -> None:
         super().reset()
         self._on_colormap_change()
+        self._on_iso_gradient_mode_change()
 
 
 class LabelLayerNode(ScalarFieldLayerNode):
