@@ -593,23 +593,32 @@ def test_active_layer():
     viewer.add_image(np.random.random((5, 5, 10, 15)))
     assert len(viewer.layers) == 1
     assert viewer.layers.selection.active == viewer.layers[0]
+    assert viewer.layers[0]._highlight_visible
 
     # Check newly added layer is active
     viewer.add_image(np.random.random((5, 6, 5, 10, 15)))
     assert len(viewer.layers) == 2
     assert viewer.layers.selection.active == viewer.layers[1]
+    assert not viewer.layers[0]._highlight_visible
+    assert viewer.layers[1]._highlight_visible
 
     # Check no active layer after unselecting all
     viewer.layers.selection.clear()
     assert viewer.layers.selection.active is None
+    assert not viewer.layers[0]._highlight_visible
+    assert not viewer.layers[1]._highlight_visible
 
     # Check selected layer is active
     viewer.layers.selection.add(viewer.layers[0])
     assert viewer.layers.selection.active == viewer.layers[0]
+    assert viewer.layers[0]._highlight_visible
+    assert not viewer.layers[1]._highlight_visible
 
     # Check no layer is active if both layers are selected
     viewer.layers.selection.add(viewer.layers[1])
     assert viewer.layers.selection.active is None
+    assert not viewer.layers[0]._highlight_visible
+    assert not viewer.layers[1]._highlight_visible
 
 
 def test_active_layer_status_update():
@@ -625,7 +634,9 @@ def test_active_layer_status_update():
     time.sleep(1)
     viewer.mouse_over_canvas = True
     viewer.cursor.position = [1, 1, 1, 1, 1]
-    assert viewer.status == viewer.layers.selection.active.get_status(
+    assert viewer._calc_status_from_cursor()[
+        0
+    ] == viewer.layers.selection.active.get_status(
         viewer.cursor.position, world=True
     )
 
@@ -996,3 +1007,46 @@ def test_make_layer_visible_after_slicing():
     layer.visible = True
 
     np.testing.assert_array_equal(layer._slice.image.raw, data[0])
+
+
+def test_get_status_text():
+    viewer = ViewerModel(ndisplay=2)
+    viewer.mouse_over_canvas = False
+    assert viewer._calc_status_from_cursor() is None
+    viewer.mouse_over_canvas = True
+    assert viewer._calc_status_from_cursor() == ('Ready', '')
+    viewer.cursor.position = (1, 2)
+    viewer.add_labels(
+        np.zeros((10, 10), dtype='uint8'), features={'a': [1, 2]}
+    )
+    viewer.tooltip.visible = False
+    assert viewer._calc_status_from_cursor() == (
+        {
+            'coordinates': ' [1 2]: 0; a: 1',
+            'layer_base': 'Labels',
+            'layer_name': 'Labels',
+            'plugin': '',
+            'source_type': '',
+        },
+        '',
+    )
+    viewer.tooltip.visible = True
+    assert viewer._calc_status_from_cursor() == (
+        {
+            'coordinates': ' [1 2]: 0; a: 1',
+            'layer_base': 'Labels',
+            'layer_name': 'Labels',
+            'plugin': '',
+            'source_type': '',
+        },
+        'a: 1',
+    )
+    viewer.update_status_from_cursor()
+    assert viewer.status == {
+        'coordinates': ' [1 2]: 0; a: 1',
+        'layer_base': 'Labels',
+        'layer_name': 'Labels',
+        'plugin': '',
+        'source_type': '',
+    }
+    assert viewer.tooltip.text == 'a: 1'
