@@ -1,13 +1,41 @@
 from unittest.mock import Mock
 
 import numpy as np
+import pytest
 
-from napari.layers.base._base_mouse_bindings import _rotate_with_box
+from napari.layers.base._base_mouse_bindings import (
+    _rotate_with_box,
+    _translate_with_box,
+)
 from napari.utils.transforms import Affine
 
 
-def test_interaction_box_rotation():
+@pytest.mark.parametrize('dims_displayed', [[0, 1], [1, 2]])
+def test_interaction_box_translation(dims_displayed):
     layer = Mock(affine=Affine())
+    layer._slice_input.displayed = [0, 1]
+    initial_affine = Affine()
+    initial_mouse_pos = np.asarray([3, 3], dtype=np.float32)
+    mouse_pos = np.asarray([6, 5], dtype=np.float32)
+    event = Mock(dims_displayed=dims_displayed, modifiers=[None])
+    _translate_with_box(
+        layer,
+        initial_affine,
+        initial_mouse_pos,
+        mouse_pos,
+        event,
+    )
+    # translate should be equal to [3, 2] from doing [6, 5] - [3, 3]
+    assert np.array_equal(
+        layer.affine.translate,
+        Affine(translate=np.asarray([3, 2], dtype=np.float32)).translate,
+    )
+
+
+@pytest.mark.parametrize('dims_displayed', [[0, 1], [1, 2]])
+def test_interaction_box_rotation(dims_displayed):
+    layer = Mock(affine=Affine())
+    layer._slice_input.displayed = [0, 1]
     initial_affine = Affine()
     initial_mouse_pos = Mock()
     # rotation handle is 8th
@@ -27,7 +55,7 @@ def test_interaction_box_rotation():
     )
     initial_center = np.asarray([3, 3], dtype=np.float32)
     mouse_pos = np.asarray([6, 5], dtype=np.float32)
-    event = Mock(dims_displayed=[0, 1], modifiers=[None])
+    event = Mock(dims_displayed=dims_displayed, modifiers=[None])
     _rotate_with_box(
         layer,
         initial_affine,
@@ -41,8 +69,10 @@ def test_interaction_box_rotation():
     assert np.allclose(layer.affine.rotate, Affine(rotate=33.69).rotate)
 
 
-def test_interaction_box_fixed_rotation():
+@pytest.mark.parametrize('dims_displayed', [[0, 1], [1, 2]])
+def test_interaction_box_fixed_rotation(dims_displayed):
     layer = Mock(affine=Affine())
+    layer._slice_input.displayed = [0, 1]
     initial_affine = Affine()
     initial_mouse_pos = Mock()
     # rotation handle is 8th
