@@ -1,5 +1,6 @@
 import sys
 from enum import auto
+from typing import ClassVar
 
 from napari.layers.shapes._shapes_models import (
     Ellipse,
@@ -62,9 +63,9 @@ class ColorMode(StringEnum):
 class Box:
     """Box: Constants associated with the vertices of the interaction box"""
 
-    WITH_HANDLE = [0, 1, 2, 3, 4, 5, 6, 7, 9]
-    LINE_HANDLE = [7, 6, 4, 2, 0, 7, 8]
-    LINE = [0, 2, 4, 6, 0]
+    WITH_HANDLE: ClassVar[list[int]] = [0, 1, 2, 3, 4, 5, 6, 7, 9]
+    LINE_HANDLE: ClassVar[list[int]] = [7, 6, 4, 2, 0, 7, 8]
+    LINE: ClassVar[list[int]] = [0, 2, 4, 6, 0]
     TOP_LEFT = 0
     TOP_CENTER = 7
     LEFT_CENTER = 1
