@@ -33,26 +33,45 @@ def test_rectangle():
     assert shape.slice_key.shape == (2, 0)
 
 
+def test_rectangle_bounding_box():
+    """Test that the bounding box is correctly updated based on edge width."""
+    data = [[10, 10], [20, 20]]
+    shape = Rectangle(data)
+    npt.assert_array_equal(
+        shape.bounding_box, np.array([[9.5, 9.5], [20.5, 20.5]])
+    )
+    shape.edge_width = 2
+    npt.assert_array_equal(shape.bounding_box, np.array([[9, 9], [21, 21]]))
+    shape.edge_width = 4
+    npt.assert_array_equal(shape.bounding_box, np.array([[8, 8], [22, 22]]))
+
+
 def test_rectangle_shift():
     shape = Rectangle(np.array([[0, 0], [1, 0], [1, 1], [0, 1]]))
-    npt.assert_array_equal(shape.bounding_box, np.array([[0, 0], [1, 1]]))
+    npt.assert_array_equal(
+        shape.bounding_box, np.array([[-0.5, -0.5], [1.5, 1.5]])
+    )
 
     shape.shift((1, 1))
     npt.assert_array_equal(
         shape.data, np.array([[1, 1], [2, 1], [2, 2], [1, 2]])
     )
-    npt.assert_array_equal(shape.bounding_box, np.array([[1, 1], [2, 2]]))
+    npt.assert_array_equal(
+        shape.bounding_box, np.array([[0.5, 0.5], [2.5, 2.5]])
+    )
 
 
 def test_rectangle_rotate():
     shape = Rectangle(np.array([[1, 2], [-1, 2], [-1, -2], [1, -2]]))
-    npt.assert_array_equal(shape.bounding_box, np.array([[-1, -2], [1, 2]]))
+    npt.assert_array_equal(
+        shape.bounding_box, np.array([[-1.5, -2.5], [1.5, 2.5]])
+    )
     shape.rotate(-90)
     npt.assert_array_almost_equal(
         shape.data, np.array([[-2, 1], [-2, -1], [2, -1], [2, 1]])
     )
     npt.assert_array_almost_equal(
-        shape.bounding_box, np.array([[-2, -1], [2, 1]])
+        shape.bounding_box, np.array([[-2.5, -1.5], [2.5, 1.5]])
     )
 
 
@@ -115,7 +134,8 @@ def test_polygon():
             [8.75174423, 17.83546002],
             [19.27325521, 7.66883038],
             [15.83450076, 10.5778984],
-        ]
+        ],
+        dtype=np.float32,
     )
     shape = Polygon(data)
     np.testing.assert_array_equal(shape.data, data)
@@ -151,7 +171,7 @@ def test_nD_polygon():
     """Test creating Shape with a random nD polygon."""
     # Test a single six vertex planar 3D polygon
     np.random.seed(0)
-    data = 20 * np.random.random((6, 3))
+    data = 20 * np.random.random((6, 3)).astype(np.float32)
     data[:, 0] = 0
     shape = Polygon(data)
     np.testing.assert_array_equal(shape.data, data)
@@ -166,7 +186,7 @@ def test_path():
     """Test creating Shape with a random path."""
     # Test a single six vertex path
     np.random.seed(0)
-    data = 20 * np.random.random((6, 2))
+    data = 20 * np.random.random((6, 2)).astype(np.float32)
     shape = Path(data)
     np.testing.assert_array_equal(shape.data, data)
     assert shape.data_displayed.shape == (6, 2)
@@ -177,7 +197,7 @@ def test_nD_path():
     """Test creating Shape with a random nD path."""
     # Test a single six vertex 3D path
     np.random.seed(0)
-    data = 20 * np.random.random((6, 3))
+    data = 20 * np.random.random((6, 3)).astype(np.float32)
     shape = Path(data)
     np.testing.assert_array_equal(shape.data, data)
     assert shape.data_displayed.shape == (6, 2)
@@ -247,22 +267,28 @@ def test_nD_ellipse():
 
 def test_ellipse_shift():
     shape = Ellipse(np.array([[0, 0], [1, 0], [1, 1], [0, 1]]))
-    npt.assert_array_equal(shape.bounding_box, np.array([[0, 0], [1, 1]]))
+    npt.assert_array_equal(
+        shape.bounding_box, np.array([[-0.5, -0.5], [1.5, 1.5]])
+    )
 
     shape.shift((1, 1))
     npt.assert_array_equal(
         shape.data, np.array([[1, 1], [2, 1], [2, 2], [1, 2]])
     )
-    npt.assert_array_equal(shape.bounding_box, np.array([[1, 1], [2, 2]]))
+    npt.assert_array_equal(
+        shape.bounding_box, np.array([[0.5, 0.5], [2.5, 2.5]])
+    )
 
 
 def test_ellipse_rotate():
     shape = Ellipse(np.array([[1, 2], [-1, 2], [-1, -2], [1, -2]]))
-    npt.assert_array_equal(shape.bounding_box, np.array([[-1, -2], [1, 2]]))
+    npt.assert_array_equal(
+        shape.bounding_box, np.array([[-1.5, -2.5], [1.5, 2.5]])
+    )
     shape.rotate(-90)
     npt.assert_array_almost_equal(
         shape.data, np.array([[-2, 1], [-2, -1], [2, -1], [2, 1]])
     )
     npt.assert_array_almost_equal(
-        shape.bounding_box, np.array([[-2, -1], [2, 1]])
+        shape.bounding_box, np.array([[-2.5, -1.5], [2.5, 1.5]])
     )
