@@ -55,25 +55,28 @@ class Line(Shape):
         if len(data) != 2:
             raise ValueError(
                 trans._(
-                    "Data shape does not match a line. A line expects two end vertices, {number} provided.",
+                    'Data shape does not match a line. A line expects two end vertices, {number} provided.',
                     deferred=True,
                     number=len(data),
                 )
             )
 
         self._data = data
+        self._bounding_box = np.array(
+            [
+                np.min(data, axis=0),
+                np.max(data, axis=0),
+            ]
+        )
+
         self._update_displayed_data()
 
-    def _update_displayed_data(self):
+    def _update_displayed_data(self) -> None:
         """Update the data that is to be displayed."""
         # For path connect every all data
         self._set_meshes(self.data_displayed, face=False, closed=False)
         self._box = create_box(self.data_displayed)
 
-        data_not_displayed = self.data[:, self.dims_not_displayed]
         self.slice_key = np.round(
-            [
-                np.min(data_not_displayed, axis=0),
-                np.max(data_not_displayed, axis=0),
-            ]
+            self._bounding_box[:, self.dims_not_displayed]
         ).astype('int')
