@@ -17,6 +17,33 @@ from napari.utils.misc import argsort
 from napari.utils.translations import trans
 
 
+def _remove_path_duplicates_np(data: np.ndarray, closed: bool):
+    # We add the first data point at the end to get the same length bool
+    # array as the data, and also to work on closed shapes; the last value
+    # in the diff array compares the last and first vertex.
+    diff = np.diff(np.append(data, data[0:1, :], axis=0), axis=0)
+    dup = np.all(diff == 0, axis=1)
+    # if the shape is closed, check whether the first vertex is the same
+    # as the last vertex, and count it as a duplicate if so
+    if closed and dup[-1]:
+        dup[0] = True
+    # we allow repeated nodes at the end for the lasso tool, which
+    # for an instant needs both the last placed point and the point at the
+    # cursor to be the same; if the lasso implementation becomes cleaner,
+    # remove this hardcoding
+    dup[-2:] = False
+    indices = np.arange(data.shape[0])
+    return data[indices[~dup]]
+
+
+try:
+    from napari.layers.shapes._accelerated_triangulate import (
+        remove_path_duplicates,
+    )
+except ImportError:
+    remove_path_duplicates = _remove_path_duplicates_np
+
+
 class Shape(ABC):
     """Base class for a single shape
 
@@ -168,7 +195,11 @@ class Shape(ABC):
     @property
     def bounding_box(self) -> np.ndarray:
         """(2, N) array, bounding box of the object."""
-        return self._bounding_box[:, self.dims_displayed]
+        # We add +-0.5 to handle edge width
+        return self._bounding_box[:, self.dims_displayed] + [
+            [-0.5 * self.edge_width],
+            [0.5 * self.edge_width],
+        ]
 
     @property
     def dims_not_displayed(self):
@@ -220,6 +251,7 @@ class Shape(ABC):
         edge : bool
             Bool which determines if the edge need to be traingulated
         """
+        data = remove_path_duplicates(data, closed=closed)
         if edge:
             centers, offsets, triangles = triangulate_edge(data, closed=closed)
             self._edge_vertices = centers
@@ -292,7 +324,7 @@ class Shape(ABC):
         self._face_vertices = self._face_vertices @ transform.T
 
         points = self.data_displayed
-
+        points = remove_path_duplicates(points, closed=self._closed)
         centers, offsets, triangles = triangulate_edge(
             points, closed=self._closed
         )
@@ -341,6 +373,7 @@ class Shape(ABC):
         if center is None:
             self.transform(transform)
         else:
+            center = np.array(center)
             self.shift(-center)
             self.transform(transform)
             self.shift(center)
@@ -362,6 +395,7 @@ class Shape(ABC):
         if center is None:
             self.transform(transform)
         else:
+            center = np.array(center)
             self.shift(-center)
             self.transform(transform)
             self.shift(center)
