@@ -8,7 +8,7 @@ from napari.utils.events.containers import EventedDict
 
 @pytest.fixture
 def regular_dict():
-    return {"A": 0, "B": 1, "C": 2}
+    return {'A': 0, 'B': 1, 'C': 2, False: '3', 4: 5}
 
 
 @pytest.fixture(params=[EventedDict])
@@ -23,14 +23,14 @@ def test_dict(request, regular_dict):
     [
         # METHOD, ARGS, EXPECTED EVENTS
         # primary interface
-        ('__getitem__', ("A",), ()),  # read
-        ('__setitem__', ("A", 3), ('changed',)),  # update
-        ('__setitem__', ("D", 3), ('adding', 'added')),  # add new entry
-        ('__delitem__', ("A",), ('removing', 'removed')),  # delete
+        ('__getitem__', ('A',), ()),  # read
+        ('__setitem__', ('A', 3), ('changed',)),  # update
+        ('__setitem__', ('D', 3), ('adding', 'added')),  # add new entry
+        ('__delitem__', ('A',), ('removing', 'removed')),  # delete
         # inherited interface
         ('key', (3,), ()),
         ('clear', (), ('removing', 'removed') * 3),
-        ('pop', ("B",), ('removing', 'removed')),
+        ('pop', ('B',), ('removing', 'removed')),
     ],
     ids=lambda x: x[0],
 )
@@ -53,6 +53,10 @@ def test_dict_interface_parity(test_dict, regular_dict, meth):
 def test_copy(test_dict, regular_dict):
     """Copying an evented dict should return a same-class evented dict."""
     new_test = test_dict.copy()
+    assert (
+        len({type(k) for k in new_test}) >= 2
+    ), 'We want at least non-string keys to test edge cases'
+
     new_reg = regular_dict.copy()
     assert id(new_test) != id(test_dict)
     assert new_test == test_dict
@@ -61,7 +65,7 @@ def test_copy(test_dict, regular_dict):
 
 
 class E:
-    def __init__(self):
+    def __init__(self) -> None:
         self.events = EmitterGroup(test=None)
 
 
@@ -72,13 +76,13 @@ def test_child_events():
     root = EventedDict()
     observed = []
     root.events.connect(lambda e: observed.append(e))
-    root["A"] = e_obj
-    e_obj.events.test(value="hi")
+    root['A'] = e_obj
+    e_obj.events.test(value='hi')
     obs = [(e.type, e.key, getattr(e, 'value', None)) for e in observed]
     expected = [
-        ('adding', "A", None),  # before we adding b into root
-        ('added', "A", e_obj),  # after b was added into root
-        ('test', "A", 'hi'),  # when e_obj emitted an event called "test"
+        ('adding', 'A', None),  # before we adding b into root
+        ('added', 'A', e_obj),  # after b was added into root
+        ('test', 'A', 'hi'),  # when e_obj emitted an event called "test"
     ]
     for o, e in zip(obs, expected):
         assert o == e
@@ -93,7 +97,7 @@ def test_evented_dict_subclass():
     class B(A, EventedDict):
         pass
 
-    dct = B({"A": 1, "B": 2})
+    dct = B({'A': 1, 'B': 2})
     assert hasattr(dct, 'events')
     assert 'boom' in dct.events.emitters
-    assert dct == {"A": 1, "B": 2}
+    assert dct == {'A': 1, 'B': 2}
