@@ -11,7 +11,6 @@ from typing import Any, Literal, Optional, Union, overload
 import npe2
 
 from napari._pydantic_compat import Color, validator
-from napari._vendor import darkdetect
 from napari.resources._icons import (
     PLUGIN_FILE_NAME,
     _theme_path,
@@ -223,6 +222,10 @@ def template(css: str, **theme):
 
 def get_system_theme() -> str:
     """Return the system default theme, either 'dark', or 'light'."""
+    try:
+        from napari._vendor import darkdetect
+    except ImportError:
+        return 'dark'
     try:
         id_ = darkdetect.theme().lower()
     except AttributeError:
