@@ -1,7 +1,7 @@
 import csv
 import os
+from importlib.metadata import version
 from pathlib import Path
-from tempfile import TemporaryDirectory
 from typing import NamedTuple
 from uuid import uuid4
 
@@ -12,6 +12,7 @@ import numpy as np
 import pytest
 import tifffile
 import zarr
+from packaging.version import parse as parse_version
 
 from napari_builtins.io._read import (
     _guess_layer_type_from_column_names,
@@ -38,7 +39,7 @@ TIFF_3D = ImageSpec((2, 15, 10), 'uint8', '.tif')
 ZARR1 = ImageSpec((10, 20, 20), 'uint8', '.zarr')
 
 
-@pytest.fixture()
+@pytest.fixture
 def write_spec(tmp_path: Path):
     def writer(spec: ImageSpec):
         image = np.random.random(spec.shape).astype(spec.dtype)
@@ -47,7 +48,7 @@ def write_spec(tmp_path: Path):
             tifffile.imwrite(str(fname), image)
         elif spec.ext == '.zarr':
             fname.mkdir()
-            z = zarr.open(str(fname), 'a', shape=image.shape)
+            z = zarr.open(store=str(fname), mode='a', shape=image.shape)
             z[:] = image
         else:
             imageio.imwrite(str(fname), image)
@@ -68,23 +69,21 @@ def test_guess_zarr_path():
     assert not _guess_zarr_path('no_zarr_suffix/data.png')
 
 
-def test_zarr():
+def test_zarr(tmp_path):
     image = np.random.random((10, 20, 20))
-    with TemporaryDirectory(suffix='.zarr') as fout:
-        z = zarr.open(fout, 'a', shape=image.shape)
-        z[:] = image
-        image_in = magic_imread([fout])
-        # Note: due to lazy loading, the next line needs to happen within
-        # the context manager. Alternatively, we could convert to NumPy here.
-        np.testing.assert_array_equal(image, image_in)
+    data_path = str(tmp_path / 'data.zarr')
+    z = zarr.open(store=data_path, mode='a', shape=image.shape)
+    z[:] = image
+    image_in = magic_imread([data_path])
+    np.testing.assert_array_equal(image, image_in)
 
 
 def test_zarr_nested(tmp_path):
     image = np.random.random((10, 20, 20))
     image_name = 'my_image'
     root_path = tmp_path / 'dataset.zarr'
-    grp = zarr.open(str(root_path), mode='a')
-    grp.create_dataset(image_name, data=image)
+    grp = zarr.open(store=str(root_path), mode='a')
+    grp.create_dataset(image_name, data=image, shape=image.shape)
 
     image_in = magic_imread([str(root_path / image_name)])
     np.testing.assert_array_equal(image, image_in)
@@ -94,8 +93,8 @@ def test_zarr_with_unrelated_file(tmp_path):
     image = np.random.random((10, 20, 20))
     image_name = 'my_image'
     root_path = tmp_path / 'dataset.zarr'
-    grp = zarr.open(str(root_path), mode='a')
-    grp.create_dataset(image_name, data=image)
+    grp = zarr.open(store=str(root_path), mode='a')
+    grp.create_dataset(image_name, data=image, shape=image.shape)
 
     txt_file_path = root_path / 'unrelated.txt'
     txt_file_path.touch()
@@ -104,24 +103,23 @@ def test_zarr_with_unrelated_file(tmp_path):
     np.testing.assert_array_equal(image, image_in[0])
 
 
-def test_zarr_multiscale():
+def test_zarr_multiscale(tmp_path):
     multiscale = [
         np.random.random((20, 20)),
         np.random.random((10, 10)),
         np.random.random((5, 5)),
     ]
-    with TemporaryDirectory(suffix='.zarr') as fout:
-        root = zarr.open_group(fout, 'a')
-        for i in range(len(multiscale)):
-            shape = 20 // 2**i
-            z = root.create_dataset(str(i), shape=(shape,) * 2)
-            z[:] = multiscale[i]
-        multiscale_in = magic_imread([fout])
-        assert len(multiscale) == len(multiscale_in)
-        # Note: due to lazy loading, the next line needs to happen within
-        # the context manager. Alternatively, we could convert to NumPy here.
-        for images, images_in in zip(multiscale, multiscale_in):
-            np.testing.assert_array_equal(images, images_in)
+    fout = str(tmp_path / 'multiscale.zarr')
+
+    root = zarr.open_group(fout, mode='a')
+    for i in range(len(multiscale)):
+        shape = 20 // 2**i
+        z = root.create_dataset(str(i), shape=(shape,) * 2)
+        z[:] = multiscale[i]
+    multiscale_in = magic_imread([fout])
+    assert len(multiscale) == len(multiscale_in)
+    for images, images_in in zip(multiscale, multiscale_in):
+        np.testing.assert_array_equal(images, images_in)
 
 
 def test_write_csv(tmpdir):
@@ -312,28 +310,37 @@ def test_add_zarr(write_spec):
     assert out[0].shape == ZARR1.shape  # type: ignore
 
 
-def test_add_zarr_1d_array_is_ignored():
+def test_add_zarr_1d_array_is_ignored(tmp_path):
+    zarr_dir = str(tmp_path / 'data.zarr')
     # For more details: https://github.com/napari/napari/issues/1471
-    with TemporaryDirectory(suffix='.zarr') as zarr_dir:
-        z = zarr.open(zarr_dir, 'w')
-        z['1d'] = np.zeros(3)
 
-        image_path = os.path.join(zarr_dir, '1d')
-        assert npe2.read([image_path], stack=False) == [(None,)]
+    z = zarr.open(store=zarr_dir, mode='w')
+    z.zeros(name='1d', shape=(3,), chunks=(3,), dtype='float32')
+
+    image_path = os.path.join(zarr_dir, '1d')
+    assert npe2.read([image_path], stack=False) == [(None,)]
 
 
-def test_add_many_zarr_1d_array_is_ignored():
+@pytest.mark.xfail(
+    parse_version(version('zarr')) >= parse_version('3.0.0a0')
+    and os.name == 'nt',
+    reason='zarr 3 return incorrect key in windows',
+    strict=True,
+)
+def test_add_many_zarr_1d_array_is_ignored(tmp_path):
     # For more details: https://github.com/napari/napari/issues/1471
-    with TemporaryDirectory(suffix='.zarr') as zarr_dir:
-        z = zarr.open(zarr_dir, 'w')
-        z['1d'] = np.zeros(3)
-        z['2d'] = np.zeros((3, 4))
-        z['3d'] = np.zeros((3, 4, 5))
+    zarr_dir = str(tmp_path / 'data.zarr')
 
-        for name in z.array_keys():
-            [out] = npe2.read([os.path.join(zarr_dir, name)], stack=False)
-            if name == '1d':
-                assert out == (None,)
-            else:
-                assert isinstance(out[0], da.Array)
-                assert out[0].ndim == int(name[0])
+    z = zarr.open(store=zarr_dir, mode='w')
+
+    z.zeros(name='1d', shape=(3,), chunks=(3,), dtype='float32')
+    z.zeros(name='2d', shape=(3, 4), chunks=(3, 4), dtype='float32')
+    z.zeros(name='3d', shape=(3, 4, 5), chunks=(3, 4, 5), dtype='float32')
+
+    for name in z.array_keys():
+        [out] = npe2.read([os.path.join(zarr_dir, name)], stack=False)
+        if name.endswith('1d'):
+            assert out == (None,)
+        else:
+            assert isinstance(out[0], da.Array), name
+            assert out[0].ndim == int(name[0])
